# `openapi-helper`

A cli tool for managing large openapi/swagger specifications.

```shell
curl https://download.stackhawk.com/hawk/tools/openapi-helper-3.5.16.zip -o ~/Downloads/openapi-helper-3.5.16.zip
unzip ~/Downloads/openapi-helper-3.5.16.zip -d ~/Downloads
```

The following commands assume you downloaded the `openapi-helper` zip file to `$HOME/Downloads` directory as shown
above.
Adjust the commands to where you downloaded and extracted the zip file.

## Usage

```shell
~/Downloads/openapi-helper-4.4.5/bin/openapi-helper -h
```

or add to your `$PATH`

```shell
export PATH="$PATH:$HOME/Downloads/openapi-helper-4.4.5/bin"
```

Following examples will presume `openapi-helper` has been added to your `$PATH`.

## Commands

### `split`

```shell
openapi-helper split stackhawk-public-api.json -o ./api-groups -c splitter.yaml
```

For splitting a large specification into smaller ones. The split out specifications
will be written as new json files into the directory specified.

The `split` command can take a YAML configuration or automatically split the API by the first
path after the common api prefix.

When automatically splitting the specification, any paths that contain a single route will be
grouped under a specification called `misc`.

For example given the following paths in a specification....

```shell
/api/v1/scans/new
/api/v1/scans/list
/api/v1/app/new
/api/v1/app/list
/api/v1/org/new
/api/v1/org/list
/api/v1/profile
/api/v1/config
```

the automatic grouping will produce the files.

```shell
scans.json
app.json
org.json
misc.json
```

The paths

```shell
/api/v1/profile
/api/v1/config
```

will be in the `misc.json` spec file.

If you want to split up your specification using a custom grouping you can supply the `-c` option
to use a YAML file describing how to group the paths.

Using the same paths above but a splitter configuration file like the following.
`splitter.yaml`

```yaml
groups:
  - name: scans
    paths:
      - /api/v1/scans/.*
  - name: org and apps
    paths:
      - /api/v1/org/.*
      - /api/v1/app/.*
```

Running the command

```yaml
openapi-helper split my-api.json -c splitter.yaml
```

will produce the following files.

```shell
scans.json
app and app.json
other.json
```

All the `/org,/app` routes will be in the `app and app.json` file and any paths not
specified the splitter YAML config will be in the `other.json` spec file.

Run `openapi-helper split -h` to see more options like `-o` to specify where split
out spec files will be written to.

### `inspect`

Example usage

```shell
$ openapi-helper inspect /stackhawk-public-api.json
spec: file:///stackhawk-public-api.json
api prefix: /api/v1/
paths: 16
request/response types: 47
```

```shell
$ openapi-helper inspect https://apidocs.stackhawk.com/openapi/611d77d75c3df60064f8c78a
spec: https://apidocs.stackhawk.com/openapi/611d77d75c3df60064f8c78a
api prefix: /api/v1/
paths: 14
request/response types: 47
```

### `convert`

Convert an openapi/swagger specification to version 3 if needed.

```shell
$ openapi-helper convert ./my-api-v2.json -o ./my-api-v3.json
```